@@ -14,7 +14,7 @@ macro_rules! mark_http_uri_normalization_orthogonal {
     ) => {
         $(
             unsafe impl<'uri, HUI> $crate::invariant::normal::HttpUriNormalizationOrthogonal<'uri>
-                for $Invariant<'uri, HUI> where HUI: $crate::base::tdd::invariant::TypeInvariant<$crate::HttpUri<'uri>> + Clone,
+                for $Invariant<'uri, HUI> where HUI: $crate::base::tdd::invariant::TypeInvariant<$crate::HttpUri<'uri>> + Clone + PartialEq,
             {
             }
         )*
