@@ -158,6 +158,12 @@ impl<'uri> Into<URI<'uri>> for HttpUri<'uri> {
     }
 }
 
+impl PartialEq for HttpUri<'_> {
+    fn eq(&self, other: &Self) -> bool {
+        self.uri == other.uri
+    }
+}
+
 impl<'uri> HttpUri<'uri> {
     const HTTP_SCHEME_DEFAULT_PORTS: [(&'static str, Option<u16>); 2] =
         [("http", Some(80)), ("https", Some(443))];
